@@ -92,7 +92,7 @@ def FindERG(data, depth=2, sort_num=20, verbose=False, figure=False):
         end = time.time()
         print("calculate time:%.2fs"%(end-start))
         print(result)
-    if depth>2 and figure=True:
+    if depth>2 and figure==True:
         plot(example)
     return result
 
